import {FC, useState} from "react";
import Taro, {useReachBottom} from "@tarojs/taro";
import {Text, View} from "@tarojs/components";
import {CoursesKey, Cur, publicApi} from "@/api/public";
import VideoCover from "@/components/videoCover/videoCover";
import styles from '../index.module.scss'
import {formatMinute} from "@/utils/time";

interface Props {
  categoryId: CoursesKey
}

export const VideoList: FC<Props> = ({categoryId}: Props) => {
  const [data, setDta] = useState<Cur[] | null>(null)
  const [index, setIndex] = useState(3)

  async function getData() {
    try {
      Taro.showLoading()
      const res = await publicApi.curs()
      const flatData = res.reduce((put, cur) => {
        put.push(cur)
        if (cur.resourceCategory?.length) {
          put.push(...cur.resourceCategory.map(d => {
            d.name = cur.name + '/' + d.name
            return d
          }))
        }
        return put
      }, [] as Cur[])

      setDta(flatData)
    } catch (e) {
    }
    Taro.hideLoading()
  }


  function rateOfLearning(id: number, class_hour: number): JSX.Element {
    console.log(id)
    return (<View>{`共${class_hour}节/已学${0}节`}</View>)
  }

  function jumpCategoryCur(id: number) {
    Taro.navigateTo({url: '/pages/business/categoryCur/categoryCur?categoryId=' + id})
  }

  useReachBottom(() => {
    if (data && data?.length > index) {
      setIndex(index + 1)
    }
  })

  Taro.useDidShow(getData)
  return (
    <>
      {data?.slice(0, index).map(d => (
        <>{
          d.courses?.[categoryId].length ? <View>
            <View className='flex justify-between align-center my-1' onClick={() => jumpCategoryCur(d.id)}>
              <Text className='font-weight'>{d.name}</Text>
              <Text className='font-20'>查看更多</Text>
            </View>
            <View className={'py-2 flex justify-between flex-wrap ' + styles.videoListBox}>
              {d.courses[categoryId].map(c => (
                <VideoCover
                  thumb={c.thumb}
                  title={c.title}
                  id={c.id}
                  depId={c.id}
                  time={formatMinute(d.courses.total_course_duration)}
                  content={rateOfLearning(c.id, c.class_hour)}
                />
              ))}
            </View>
          </View> : null
        }</>
      ))}
    </>
  )
}
